@@ -1,7 +1,7 @@
 from twitchAPI.twitch import Twitch
 from twitchAPI.webhook import TwitchWebHook
-from twitchAPI.oauth import UserAuthenticator, refresh_access_token
+from twitchAPI.oauth import UserAuthenticator, refresh_access_token, validate_token, revoke_token
 from twitchAPI.types import *
 from twitchAPI.pubsub import PubSub
 
-VERSION = (2, 2, 5)
+VERSION = (2, 3, 0)
