@@ -39,7 +39,7 @@ Class Documentation:
 ********************
 """
 from .twitch import Twitch
-from .helper import build_url, build_scope, get_uuid, TWITCH_AUTH_BASE_URL
+from .helper import build_url, build_scope, get_uuid, TWITCH_AUTH_BASE_URL, fields_to_enum
 from .types import AuthScope, InvalidRefreshTokenException, UnauthorizedException
 from typing import List, Union
 import webbrowser
@@ -83,6 +83,40 @@ def refresh_access_token(refresh_token: str,
     return data['access_token'], data['refresh_token']
 
 
+def validate_token(access_token: str) -> dict:
+    """Helper function for validating a user or app access token.
+
+    https://dev.twitch.tv/docs/authentication#validating-requests
+
+    :param str access_token: either a user or app OAuth access token
+    :return: response from the api
+    :rtype: dict
+    """
+    header = {'Authorization': f'OAuth {access_token}'}
+    url = build_url(TWITCH_AUTH_BASE_URL + 'oauth2/validate', {})
+    result = requests.get(url, headers=header)
+    data = result.json()
+    return fields_to_enum(data, ['scopes'], AuthScope, None)
+
+
+def revoke_token(client_id: str, access_token: str) -> bool:
+    """Helper function for revoking a user or app OAuth access token.
+
+    https://dev.twitch.tv/docs/authentication#revoking-access-tokens
+
+    :param str client_id: client id belonging to the access token
+    :param str access_token: user or app OAuth access token
+    :rtype: bool
+    :return: :code:`True` if revoking succeeded, otherwise :code:`False`
+    """
+    url = build_url(TWITCH_AUTH_BASE_URL + 'oauth2/revoke', {
+        'client_id': client_id,
+        'token': access_token
+    })
+    result = requests.post(url)
+    return result.status_code == 200
+
+
 class UserAuthenticator:
     """Simple to use client for the Twitch User authentication flow.
 
