@@ -42,7 +42,9 @@ Short code example:
     user_info = twitch.get_users(logins=['my_twitch_user'])
     user_id = user_info['data'][0]['id']
     # basic setup
-    hook = TwitchWebHook("https://my.cool.domain.net:8080", 'my_app_id', 8080)
+    # Please note that the first parameter is the domain your webhook is reachable from the outside, the last parameter
+    # is the port that the Webhook should use
+    hook = TwitchWebHook("https://my.cool.domain.net:443", 'my_app_id', 8080)
     hook.authenticate(twitch)
     hook.start()
     print('subscribing to hook:')
@@ -66,14 +68,21 @@ succeeded but the final handshake failed.
 
 You can unsubscribe from a webhook subscription at any time by using :meth:`~twitchAPI.webhook.TwitchWebHook.unsubscribe`
 
-If :attr:`~.TwitchWebHook.unsubscribe_on_stop` is True (default), you dont need to manually unsubscribe from topics.
+If :attr:`~.TwitchWebHook.unsubscribe_on_stop` is True (default), you don't need to manually unsubscribe from topics.
 
-By deafult, subscriptions will be automatically renewed one minute before they run out for as long as the
+By default, subscriptions will be automatically renewed one minute before they run out for as long as the
 webhook is running.
 
 You can also use :meth:`~twitchAPI.webhook.TwitchWebHook.unsubscribe_all` to unsubscribe from all topic subscriptions at
 once. This will also unsubscribe from topics that where left over from a previous run.
 
+***********************
+Fixing typical problems
+***********************
+
+* Make sure that your set URL is reachable from outside your network
+* Make sure that you use a non self signed SSL certificate (use one from e.g. Let's Encrypt) if you use any Authentication
+
 ********************
 Class Documentation:
 ********************
@@ -299,12 +308,11 @@ class TwitchWebHook:
                            callback_func,
                            auth_type: AuthType,
                            auth_scope: List[AuthScope]) -> bool:
-        if not self.__twitch.has_required_auth(auth_type, auth_scope):
+        if auth_type != AuthType.NONE and not self.__twitch.has_required_auth(auth_type, auth_scope):
             raise UnauthorizedException('required authentication not set or missing auth scope')
         success = self._subscribe(callback_path+"?uuid=" + str(uuid), url)
         if success:
             self.__add_callable(uuid, callback_func)
-            # self.__urls[uuid] = url
             self.__active_webhooks[uuid] = {
                 'url': url,
                 'callback': callback_func,
